StaticContentHandler (Selenium RC Server (Coreless) 1.0.1 API)
Date: 2009-06-09

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

## org.openqa.selenium.server
Class StaticContentHandler

    java.lang.Object
      org.mortbay.http.handler.AbstractHttpHandler
          org.mortbay.http.handler.ResourceHandler
              org.openqa.selenium.server.StaticContentHandler

All Implemented Interfaces:
  java.io.Serializable, org.mortbay.http.HttpHandler, org.mortbay.util.LifeCycle

    public class StaticContentHandler

extends org.mortbay.http.handler.ResourceHandler

See Also:
  Serialized Form

Field Summary
`static int` | `SERVER_DELAY`

Constructor Summary
`StaticContentHandler(java.lang.String debugURL, boolean proxyInjectionMode)`

Method Summary
`void` | `addStaticContent(ResourceLocator locator)`
`protected void` | `callSuperHandle(java.lang.String pathInContext, java.lang.String pathParams, org.mortbay.http.HttpRequest httpRequest, org.mortbay.http.HttpResponse httpResponse)`
`protected org.mortbay.util.Resource` | `getResource(java.lang.String pathInContext)`
`static boolean` | `getSlowResources()`
`void` | `handle(java.lang.String pathInContext, java.lang.String pathParams, org.mortbay.http.HttpRequest httpRequest, org.mortbay.http.HttpResponse httpResponse)`
`void` | `sendData(org.mortbay.http.HttpRequest request, org.mortbay.http.HttpResponse response, java.lang.String pathInContext, org.mortbay.util.Resource resource, boolean writeHeaders)`
`static void` | `setSlowResources(boolean slowResources)`

Methods inherited from class org.mortbay.http.handler.ResourceHandler
`getAllowedMethods, getAllowedString, getMinGzipLength, getRedirectWelcome, handleGet, isAcceptRanges, isDirAllowed, isMethodAllowed, setAcceptRanges, setAllowedMethods, setDirAllowed, setMinGzipLength, setRedirectWelcome, start, stop, writeHeaders`

Methods inherited from class org.mortbay.http.handler.AbstractHttpHandler
`getHttpContext, getName, handleTrace, initialize, isStarted, setName, toString`

Methods inherited from class java.lang.Object
`clone, equals, finalize, getClass, hashCode, notify, notifyAll, wait, wait, wait`

Field Detail

### SERVER_DELAY

    public static final int SERVER_DELAY

See Also:
  Constant Field Values

Constructor Detail

### StaticContentHandler

    public StaticContentHandler(java.lang.String debugURL,
                                boolean proxyInjectionMode)

Method Detail

### handle

    public void handle(java.lang.String pathInContext,
                       java.lang.String pathParams,
                       org.mortbay.http.HttpRequest httpRequest,
                       org.mortbay.http.HttpResponse httpResponse)
                throws java.io.IOException

  Specified by:
    `handle` in interface `org.mortbay.http.HttpHandler`
  Overrides:
    `handle` in class `org.mortbay.http.handler.ResourceHandler`
  Throws:
    `java.io.IOException`

### callSuperHandle

    protected void callSuperHandle(java.lang.String pathInContext,
                                   java.lang.String pathParams,
                                   org.mortbay.http.HttpRequest httpRequest,
                                   org.mortbay.http.HttpResponse httpResponse)
                            throws java.io.IOException

  Throws:
    `java.io.IOException`

### getResource

    protected org.mortbay.util.Resource getResource(java.lang.String pathInContext)
                                             throws java.io.IOException

  Overrides:
    `getResource` in class `org.mortbay.http.handler.ResourceHandler`
  Throws:
    `java.io.IOException`

### addStaticContent

    public void addStaticContent(ResourceLocator locator)

### sendData

    public void sendData(org.mortbay.http.HttpRequest request,
                         org.mortbay.http.HttpResponse response,
                         java.lang.String pathInContext,
                         org.mortbay.util.Resource resource,
                         boolean writeHeaders)
                  throws java.io.IOException

  Overrides:
    `sendData` in class `org.mortbay.http.handler.ResourceHandler`
  Throws:
    `java.io.IOException`

### setSlowResources

    public static void setSlowResources(boolean slowResources)

### getSlowResources

    public static boolean getSlowResources()

Overview | Package | Class | Use | Tree | Deprecated | Index | Help
PREV CLASS NEXT CLASS | FRAMES NO FRAMES
SUMMARY: NESTED | FIELD | CONSTR | METHOD | DETAIL: FIELD | CONSTR | METHOD

Copyright © 2009. All Rights Reserved.